// Programmed using the knockoff Pro Micro boards - use Arduino/Genuino Micro as board type.
// Watch out - your board's name might change and you'll have to select it again in Tools/Port after
// you program it the first time.

// Anything on a line after "//" is commented out - the microcontroller will ignore it!

// Libraries 
// You need to install thse libraries from the menu bar -> 
// Sketch/Include Library/Manage Libraries, and then search for the word in front of the .h
#include <elapsedMillis.h>
#include <MIDIUSB.h>

//// MIDI Setup
// Send MIDI on channel 1
int channel = 1; 

// Send Control Change messages on CC #7
int CC = 7;      

// A variable for the lower pressure limit
int lowP = 0;    

// A variable for the high pressure limit - you should set this appropriately after running
// Gravity debug - a value  in the range 260-300 is probably right
int highP = 260;

// A timer variable that is used to limit the number of messages that are sent
elapsedMillis timeElapsed;

// The setup loop runs once:
void setup() {
  lowP = analogRead(A0);
}

// The main loop runs repeatedly forever
void loop() {
  // if 20 ms have elapsed since the last message was sent, send another one
  if(timeElapsed > 20){
    timeElapsed = 0;
    // read the pressure and map the current pressure reading to an appropriate MIDI CC
    // value in the range 0-127
    int val = constrain(map(analogRead(A0),lowP+3,highP,0,120),0,120); 
    // Send a CC value
    sendCC(val);
  }
}

// A function to send a MIDI Control Change Message
void sendCC(byte value) {
  midiEventPacket_t CCdata = {0x0B, 0xB0 | channel, CC, value};
  MidiUSB.sendMIDI(CCdata);
  MidiUSB.flush();
}
